<?php
/**
 * Importer helper file
 *
 * @author StandaloneTech
 * @package StandaloneTech
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Importer helper class
 *
 * @author StandaloneTech
 */
class WOO_Wallet_Importer_Helper {

	const DELIMITER = WOO_WALLET_IMPORTER_DELIMITER;

	/**
	 * File utility functions.
	 *
	 * @param string $filename Filename.
	 * @param string $mode mode.
	 * @return file
	 */
	public function fopen( $filename, $mode = 'r' ) {
		return fopen( $filename, $mode );
	}
	/**
	 * File utility functions.
	 *
	 * @param resource $handle Handle.
	 * @param integer  $length Length.
	 * @return array|false
	 */
	public function fgetcsv( $handle, $length = 0 ) {
		return fgetcsv( $handle, $length, self::DELIMITER );
	}
	/**
	 * File utility functions.
	 *
	 * @param resource $fp Handle.
	 * @return bool
	 */
	public function fclose( $fp ) {
		return fclose( $fp );
	}
	/**
	 * Perse columns.
	 *
	 * @param object $obj object.
	 * @param array  $array  array.
	 * @return object
	 */
	public function parse_columns( &$obj, $array ) {
		if ( ! is_array( $array ) || count( $array ) == 0 ) {
			return false;
		}

		$bom = pack( 'CCC', 0xef, 0xbb, 0xbf );
		if ( 0 === strncmp( $array[0], $bom, 3 ) ) {
			$array[0] = substr( $array[0], 3 );
		}

		$keys   = array_keys( $array );
		$values = array_values( $array );

		$obj->column_indexes = array_combine( $values, $keys );
		$obj->column_keys    = array_combine( $keys, $values );
	}
	/**
	 * Get CSV data.
	 *
	 * @param object $obj object.
	 * @param array  $array array.
	 * @param string $key key.
	 * @return array | bool
	 */
	public function get_data( $obj, &$array, $key ) {
		if ( ! isset( $obj->column_indexes ) || ! is_array( $array ) || count( $array ) == 0 ) {
			return false;
		}

		if ( isset( $obj->column_indexes[ $key ] ) ) {
			$index = $obj->column_indexes[ $key ];
			if ( isset( $array[ $index ] ) && ! empty( $array[ $index ] ) ) {
				$value = $array[ $index ];
				unset( $array[ $index ] );
				return $value;
			} elseif ( isset( $array[ $index ] ) ) {
				unset( $array[ $index ] );
			}
		}

		return false;
	}
	/**
	 * Get CSV row.
	 *
	 * @param resource $csv CSV file.
	 * @param array    $row row.
	 * @return array | bool
	 */
	public function get_row( $csv, $row ) {
		$handle  = $this->fopen( $csv, 'r' );
		$counter = 0;
		while ( ( $data = $this->fgetcsv( $handle ) ) !== false ) {
			$counter++;
			if ( $row == $counter ) {
				return $data;
			}
		}
		$this->fclose( $handle );
		return false;
	}

}
